@@ -11,7 +11,7 @@
 #' Currently, the other \code{texmexFamily} objects available are \code{gev}
 #' which results in fitting a generalized extreme value (GEV) distribution to
 #' the data, \code{gpdIntCensored} which can be used to fit the GPD to data which has
-#' been rounded to a given numebr of decimal places by recognisiing the data as
+#' been rounded to a given number of decimal places by recognisiing the data as
 #' interval censored, and \code{egp3} which fits the extended generalized Pareto
 #' distribution version 3 of Papastathopoulos and Tawn (2013).
 #'
@@ -61,7 +61,10 @@
 #' When \code{method = "bootstrap"}, summaries of the bootstrap distribution
 #' and the bootstrap estimate of bias are displayed.
 #'
-#' @param y Either a numeric vector or the name of a variable in \code{data}.
+#' @param y Either a numeric vector, the name of a variable in \code{data}
+#' or a string representing the name of a
+#' variable in \code{data}. NOTE THAT the use of non-standard evaluation is
+#' likely to be removed from future versions of texmex.
 #' @param data A data frame containing \code{y} and any covariates.
 #' @param family An object of class 'texmexFamily'. Defaults to
 #' \code{family=gpd} and a generalized Pareto distribution (GPD) is fit to the data.
@@ -150,6 +153,7 @@
 #' @param jump.const Control parameter for the Metropolis algorithm.
 #' @param verbose Whether or not to print progress to screen. Defaults to
 #' \code{verbose=TRUE}.
+#' @param call Used internally, defaults to \code{call = NULL}.
 #' @param R The number of parametric bootstrap samples to run when \code{method
 #' = "bootstrap"} is requested. Defaults to 1000.
 #' @param cores The number of cores to use when bootstrapping. Defaults to
@@ -277,21 +281,67 @@
 #'   plot(mod)
 #'   }
 #'
-#' @export evm
-evm <- function(y, data, family=gpd, ...){
-  theCall <- match.call()
-  if (!missing(data)) {
-      y <- ifelse(deparse(substitute(y))== "substitute(y)", deparse(y),deparse(substitute(y)))
-      y <- formula(paste(y, "~ 1"))
-      y <- model.response(model.frame(y, data=data))
+#'
+#' @rdname evm
+#' @export
+evm <- function(y, data = NULL, ...) {
+  dec <- is.declustered(y)
+
+  if (dec){
+    evm.declustered(y, data, ...)
+  } else {
+    mf <- match.call()
+    m <- match(c("y", "data"), names(mf), 0L)
+    mf <- mf[c(1L, m)]
+
+    if (inherits(mf[[2]], c("name", "call"))){
+      formula_string <- paste(deparse(mf[[2]]), "~ 1")
+    } else if (inherits(mf[[2]], "character")){
+      formula_string <- paste(mf[[2]], "~ 1")
+    }
+
+    if (exists("formula_string")){
+      use_formula <- as.formula(formula_string, env = parent.frame())
+
+      mf[[2L]] <- use_formula
+      mf[[1L]] <- quote(evmReal)
+      y <- eval(mf, parent.frame())
+    } else {
+      y <- eval(mf[[2]], parent.frame())
+    }
+
+    ##UseMethod("evm", object = y)
+    call <- match.call(expand.dots = TRUE)
+    evm.default(y, data = data, ..., call = call)
   }
-  UseMethod("evm", y)
+}
+
+is.declustered <- function(x){
+  res <- try(inherits(x, "declustered"), silent = TRUE)
+
+  if (!inherits(res, "try-error") && res){
+    TRUE
+  } else {
+    FALSE
+  }
+}
+
+
+#' @rdname evm
+#' @export
+evmReal <- function(y, data) {
+  mf <- match.call()
+  m <- match(c("y", "data"), names(mf), 0L)
+  mf <- mf[c(1L, m)]
+  names(mf)[2] <- ""
+  mf[[1L]] <- quote(stats::model.frame)
+  mf <- eval(mf, parent.frame())
+  model.response(mf)
 }
 
 #' @rdname evm
 #' @export
-evm.default <-
-function (y, data, family=gpd, th= -Inf, qu,
+evm.default <- function (y, data = NULL, family=gpd, th= -Inf, qu,
           ..., # arguments specific to family such as phi = ~ 1
           penalty = NULL, prior = "gaussian",
           method = "optimize", cov="observed",
@@ -300,9 +350,15 @@ function (y, data, family=gpd, th= -Inf, qu,
           iter = 40500, burn=500, thin = 4, chains = 1,
           proposal.dist = c("gaussian", "cauchy"),
           jump.cov, jump.const=NULL,
-          R=1000, cores=NULL, export=NULL, verbose=TRUE) {
+          R=1000, cores=NULL, export=NULL, verbose=TRUE, call = NULL) {
 
-    modelParameters <- texmexParameters(theCall, family,...)
+    if (!is.null(call)){
+      theCall <- call
+    } else {
+      theCall <- match.call()
+    }
+
+    modelParameters <- texmexParameters(theCall, family, ...)
 
     ##################### Sort out method, penalty/prior, trace...
 
@@ -314,9 +370,6 @@ function (y, data, family=gpd, th= -Inf, qu,
 
     ############################## Construct data to use...
 
-    if (missing(data)){ data <- NULL }
-    else { y <- deparse(substitute(y)) }
-
     # Get list containing response (y) and design matrix for each parameter
     modelData <- texmexPrepareData(y, data, modelParameters)
 
@@ -367,6 +420,7 @@ function (y, data, family=gpd, th= -Inf, qu,
         o <- evmBoot(o, R=R, cores=cores, export=export)
     }
 
+    o$call <- theCall
+
     o
 }
-
