@@ -175,16 +175,40 @@
 #' par(mfrow=c(2,2)); plot(so2.d.gpd.o3)
 #'
 #' @export extremalIndex
-extremalIndex <- function(y,data=NULL,threshold)
-# intevals estimator of the Extremal Index, Ferro and Segers JRSS B (2003)
+extremalIndex <- function(y, data=NULL, threshold)
+# intervals estimator of the Extremal Index, Ferro and Segers JRSS B (2003)
 # assumes data points equally spaced in time and no missing data (ie missing time points)
 {
-  if (!missing(data)) {
-     y <- ifelse(deparse(substitute(y))== "substitute(y)", deparse(y),deparse(substitute(y)))
-     y <- formula(paste(y, "~ 1"))
-     y <- model.response(model.frame(y, data=data))
+  if (FALSE){##} & !missing(data)) {
+     y <- ifelse(deparse(substitute(y)) == "substitute(y)", deparse(y),
+                 deparse(substitute(y)))
+     y <- formula(paste(y, "~ 1", collapse = " "))
+     y <- model.response(model.frame(y, data = data))
   }
+
   theCall <- match.call()
+
+  mf <- match.call()
+  m <- match(c("y", "data"), names(mf), 0L)
+  mf <- mf[c(1L, m)]
+
+  if (inherits(mf[[2]], c("name", "call"))){
+    formula_string <- paste(deparse(mf[[2]]), "~ 1")
+  } else if (inherits(mf[[2]], "character")){
+    formula_string <- paste(mf[[2]], "~ 1")
+  }
+
+  if (exists("formula_string")){
+    use_formula <- as.formula(formula_string, env = parent.frame())
+
+    mf[[2L]] <- use_formula
+    mf[[1L]] <- quote(evmReal)
+    y <- eval(mf, parent.frame())
+  } else {
+    y <- eval(mf[[2]], parent.frame())
+  }
+
+
   timeAll <- 1:length(y)
   thExceedance <- y > threshold
   thExceedanceProb <- mean(thExceedance)
@@ -218,8 +242,7 @@ extremalIndex <- function(y,data=NULL,threshold)
 }
 
 #' @export
-print.extremalIndex <- function(x,...)
-{
+print.extremalIndex <- function(x,...){
   cat("\nLength of original series",x$TotalN,"\n")
   cat("Threshold", x$threshold,"\n")
   cat("Number of Threshold Exceedances",x$nExceed,"\n")
@@ -228,14 +251,15 @@ print.extremalIndex <- function(x,...)
 }
 
 #' @export
-plot.extremalIndex <- function(x,...)
-{
+plot.extremalIndex <- function(x,...){
   NormInterExceedTimes <- x$interExceedTimes * x$thExceedanceProb
 
   StdExpQuantiles <- qexp(ppoints(NormInterExceedTimes))
   Theta <- x$EIintervals
 
-  plot(StdExpQuantiles, sort(NormInterExceedTimes),xlab="Standard Exponential Quantiles",ylab="Interexceedance Times",cex=0.7,...)
+  plot(StdExpQuantiles, sort(NormInterExceedTimes),
+       xlab="Standard Exponential Quantiles",
+       ylab="Interexceedance Times",cex=0.7,...)
   abline(v=qexp(1-Theta))
   abline(a = -qexp(1-Theta)/Theta, b=1/Theta)
   title(paste("Threshold=",x$threshold))
@@ -243,31 +267,67 @@ plot.extremalIndex <- function(x,...)
 }
 
 #' @export
-declust <- function(y, r=NULL, data=NULL, ...)
-{
-  if (!missing(data)) {
-     y <- deparse(substitute(y))
-     y <- formula(paste(y, "~ 1"))
-     y <- model.response(model.frame(y, data=data))
+declust <- function(y, r = NULL, data = NULL, ...){
+  res <- try(declust.extremalIndex(y, r, data, ...), silent = TRUE)
+  if (inherits(res, "try-error")){
+    mf <- match.call()
+    m <- match(c("y", "data"), names(mf), 0L)
+    mf <- mf[c(1L, m)]
+
+    if (inherits(mf[[2]], c("name", "call"))){
+      formula_string <- paste(deparse(mf[[2]]), "~ 1")
+    } else if (inherits(mf[[2]], "character")){
+      formula_string <- paste(mf[[2]], "~ 1")
+    }
+
+    if (exists("formula_string")){
+      use_formula <- as.formula(formula_string, env = parent.frame())
+
+      mf[[2L]] <- use_formula
+      mf[[1L]] <- quote(evmReal)
+      y <- eval(mf, parent.frame())
+    } else {
+      y <- eval(mf[[2]], parent.frame())
+    }
+    UseMethod("declust", y)
+  } else {
+    res
   }
-  UseMethod("declust", y)
 }
 
 #' @export
-declust.default <- function(y,r=NULL,data=NULL,verbose=TRUE,...)
-{
-  if(missing(data)){
+declust.default <- function(y, r=NULL, data=NULL, verbose=TRUE,...){
+  mf <- match.call()
+  m <- match(c("y", "data"), names(mf), 0L)
+  mf <- mf[c(1L, m)]
+
+  if (inherits(mf[[2]], c("name", "call"))){
+    formula_string <- paste(deparse(mf[[2]]), "~ 1")
+  } else if (inherits(mf[[2]], "character")){
+    formula_string <- paste(mf[[2]], "~ 1")
+  }
+
+  if (exists("formula_string")){
+    use_formula <- as.formula(formula_string, env = parent.frame())
+
+    mf[[2L]] <- use_formula
+    mf[[1L]] <- quote(evmReal)
+    y <- eval(mf, parent.frame())
+  } else {
+    y <- eval(mf[[2]], parent.frame())
+  }
+
+  if(!is.null(data)){
     ei <- extremalIndex(y,...)
   } else {
-    ei <- extremalIndex(substitute(y),data,...)
+    ei <- extremalIndex(y,...)
   }
 
-  declust(ei, r=r)
+  declust.extremalIndex(ei, r=r)
 }
 
 #' @export
-declust.extremalIndex <- function(y,r=NULL,...)
-{
+declust.extremalIndex <- function(y, r=NULL,...){
   theCall <- match.call()
   Times <- y$interExceedTimes
   sTimes <- sort(Times, decreasing=TRUE)
@@ -333,9 +393,9 @@ plot.declustered <- function(x,ylab="Data",...){
 
 #' @export
 bootExtremalIndex <- function(x){
-  if( class(x) == "extremalIndex"){
+  if(inherits(x, "extremalIndex")){
     x <- declust(x)
-  } else if(class(x) != "declustered"){
+  } else if (!inherits(x, "declustered")){
     stop("x must be of class extremalIndex or declust")
   }
   nc <- length(x$sizes)
@@ -357,14 +417,32 @@ bootExtremalIndex <- function(x){
 }
 
 #' @export
-extremalIndexRangeFit <- function(y,data=NULL,umin=quantile(y,.5),umax=quantile(y,0.95),nint=10,nboot=100,alpha=.05, estGPD=TRUE, verbose=TRUE, trace=10, ...){
+extremalIndexRangeFit <- function(y, data=NULL, umin=quantile(y,.5),
+                                  umax=quantile(y,0.95), nint=10, nboot=100,
+                                  alpha=.05, estGPD=TRUE, verbose=TRUE, trace=10,
+                                  ...){
 
-  if (!missing(data)) {
-     y <- deparse(substitute(y))
-     y <- formula(paste(y, "~ 1"))
-     y <- model.response(model.frame(y, data=data))
+  mf <- match.call()
+  m <- match(c("y", "data"), names(mf), 0L)
+  mf <- mf[c(1L, m)]
+
+  if (inherits(mf[[2]], c("name", "call"))){
+    formula_string <- paste(deparse(mf[[2]]), "~ 1")
+  } else if (inherits(mf[[2]], "character")){
+    formula_string <- paste(mf[[2]], "~ 1")
   }
 
+  if (exists("formula_string")){
+    use_formula <- as.formula(formula_string, env = parent.frame())
+
+    mf[[2L]] <- use_formula
+    mf[[1L]] <- quote(evmReal)
+    y <- eval(mf, parent.frame())
+  } else {
+    y <- eval(mf[[2]], parent.frame())
+  }
+
+
   EI <- SH <- SC <-
     list(m=numeric(nint),boot=matrix(0,nrow=nint,ncol=nboot))
 
@@ -373,9 +451,9 @@ extremalIndexRangeFit <- function(y,data=NULL,umin=quantile(y,.5),umax=quantile(
     if(verbose){
       cat("\n", i,"of",nint,"thresholds: bootstrap ... ")
     }
-    z <- extremalIndex(y,threshold=u[i])
+    z <- extremalIndex(y, threshold=u[i])
     EI$m[i] <- z$EIintervals
-    d <- declust(z)
+    d <- declust.extremalIndex(z)
     if(estGPD){
       gpd.d <- evm.declustered(d)
       co.d <- coef(gpd.d)
@@ -391,10 +469,10 @@ extremalIndexRangeFit <- function(y,data=NULL,umin=quantile(y,.5),umax=quantile(
       z.b <- extremalIndex(boot,threshold=u[i])
       EI$boot[i,j] <- z.b$EIintervals
       if(estGPD){
-        z.d <- declust(z.b)
+        z.d <- declust.extremalIndex(z.b)
         z.d$clusterMaxima <- rgpd(z.d$nClusters,exp(co.d[1]),co.d[2],u=z.d$threshold)
         gpd.b <- try(evm.declustered(z.d,cov="numeric"))
-        if(class(gpd.b) == "try-error"){
+        if(inherits(gpd.b, "try-error")){
           SH$boot[i,j] <- SC$boot[i,j] <- NA
         } else {
           SH$boot[i,j] <- coef(gpd.b)[2]
@@ -470,23 +548,27 @@ plot.extremalIndexRangeFit <- function(x,addNexcesses=TRUE,estGPD=TRUE,...){
 
 #' @export
 evm.declustered <- function(y, data=NULL, family=gpd, ...){
-  myCall <- match.call()
+  theCall <- match.call(expand.dots = TRUE)
 
   if(is.null(y$data)){
-    res <- evm(y$clusterMaxima, th = y$threshold, family=family, ...)
+    res <- eval(evm.default(y$clusterMaxima, th = y$threshold,
+                            family=family, data = data, ..., call = theCall))
   } else {
     response <- y$clusterMaxima
-    dat <- cbind(response,y$data[y$y>y$threshold,][y$isClusterMax,])
-    res <- evm(response, data=dat, th = y$threshold, family=family, ...)
+    dat <- cbind(response, y$data[y$y > y$threshold,][y$isClusterMax, ])
+    res <- evm.default(response, data = dat, th = y$threshold,
+                       family=family, ..., call = theCall)
   }
 
+  res$call <- theCall
+
   clusterRate <- max(y$clusters) / length(y$y)
-  if(class(res) == "evmOpt"){
+  if(inherits(res, "evmOpt")){
     res$rate <- clusterRate
-  } else if(class(res) == "evmSim") {
+  } else if(inherits(res, "evmSim")) {
     res$map$rate <- clusterRate
   }
-  res$call <- myCall
+
   res
 }
 
